<?php
/*
 * Set up the content width value based on the theme's design.
 */
if (!function_exists('icoach_setup')) :
    function icoach_setup() {
        global $content_width;
        if (!isset($content_width)) {
            $content_width = 870;
        }
        // Make icoach theme available for translation.
        load_theme_textdomain('icoach', get_template_directory() . '/languages');

        // Add RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');

        // register menu 
        register_nav_menus(array(
            'primary' => __('Top Header Menu', 'icoach'),
            'footer' => __('Footer Menu', 'icoach'),
        ));

        // Featured image support
        add_theme_support('post-thumbnails');
        add_theme_support( 'custom-logo', array(
            'height'      => 31,
            'width'       => 113,
            'flex-height' => true,
            'flex-width'  => true,
            'header-text' => array( 'img-responsive', 'site-description' ), 
        ) );
        // Switch default core markup for search form, comment form, and commen, to output valid HTML5.
        add_theme_support('html5', array(
            'search-form', 'comment-form', 'comment-list',
        ));
        add_theme_support('custom-background', array(
            'default-color' => 'f5f5f5',
        ));
        // Add support for featured content.
        add_theme_support('featured-content');
        // This theme uses its own gallery styles.
        add_filter('use_default_gallery_style', '__return_false');
        /* slug setup */
        add_theme_support('title-tag');
    }
endif; // icoach_setup
add_action('after_setup_theme', 'icoach_setup');
/*
 * Register OpenSans Google font for niche.
 */
function icoach_font_url() {
    $icoach_font_url = '';
    
    if ('off' !== _x('on', 'OpenSans font: on or off', 'icoach')) {
        $icoach_font_url = add_query_arg('family', urlencode('OpenSans:300,400,700,900,300italic,400italic,700italic'), "//fonts.googleapis.com/css?family=Open+Sans");
    }
    return $icoach_font_url;
}
add_filter('nav_menu_css_class' , 'special_nav_class' , 10 , 2);

function special_nav_class($classes, $item){
     if( in_array('current-menu-item', $classes) ){
             $classes[] = 'active ';
     }
     return $classes;
}
define( 'HEADER_IMAGE_WIDTH', apply_filters( 'basic_header_image_width', 1920 ) );
define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'basic_header_image_height', 1435 ) );

function icoach_owl_carousel_initialization(){?>
<script type="text/javascript">
    jQuery('.owl-carousel').owlCarousel({
        loop: true,
        margin: 30,
        nav: true,
        responsive: {
            0: {
                items: 1
            },
            768: {
                items: 2
            },
            1000: {
                items: 2
            }
        }
    })
    jQuery(document).ready(function() {    
        setTimeout(function(){
            jQuery('body').addClass('loaded');
        }, 3000);
        
    });
</script>
<?php }
add_action( 'wp_footer', 'icoach_owl_carousel_initialization' );
/** * Enqueue css and js files **/
require get_template_directory() . '/functions/theme-default-setup.php';
require get_template_directory() . '/functions/enqueue-files.php';
require get_template_directory() . '/functions/custom-header.php';
require get_template_directory() . '/functions/theme-customization.php';
require get_template_directory() . '/functions/home-customization.php';
require_once get_template_directory() . '/inc/class-tgm-plugin-activation.php';
/*
* TGM plugin activation register hook 
*/
add_action( 'tgmpa_register', 'iCoachActionTgmPluginActiveRegisterRequiredPlugins' );
function iCoachActionTgmPluginActiveRegisterRequiredPlugins() {
    if(class_exists('TGM_Plugin_Activation')){
      $plugins = array(
        array(
           'name'      => __('Contact Form 7','icoach'),
           'slug'      => 'contact-form-7',
           'required'  => true,
        ),
      );
      $config = array(
        'default_path' => '',
        'menu'         => 'icoach-install-plugins',
        'has_notices'  => true,
        'dismissable'  => true,
        'dismiss_msg'  => '',
        'is_automatic' => false,
        'message'      => '',
        'strings'      => array(
           'page_title'                      => __( 'Install Required Plugins', 'icoach' ),
           'menu_title'                      => __( 'Install Plugins', 'icoach' ),
           'installing'                      => __( 'Installing Plugin: %s', 'icoach' ), 
           'oops'                            => __( 'Something went wrong with the plugin API.', 'icoach' ),
           'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.','icoach' ), 
           'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.','icoach' ), 
           'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','icoach' ), 
           'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','icoach' ), 
           'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','icoach' ), 
           'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','icoach' ), 
           'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','icoach' ), 
           'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','icoach' ), 
           'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','icoach' ),
           'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','icoach' ),
           'return'                          => __( 'Return to Required Plugins Installer', 'icoach' ),
           'plugin_activated'                => __( 'Plugin activated successfully.', 'icoach' ),
           'complete'                        => __( 'All plugins installed and activated successfully. %s', 'icoach' ), 
           'nag_type'                        => 'updated'
        )
      );
      iCoach( $plugins, $config );
    }
}
//Pro Feature Menu
function iCoachMenuSettings() {
    $iCoachMenu = array(
        'page_title' => __('iCoach Pro Features', 'icoach'),
        'menu_title' => __('iCoach Pro Features', 'icoach'),
        'capability' => 'edit_theme_options',
        'menu_slug' => 'icoach',
        'callback' => 'iCoachProPage'
    );
    return apply_filters('icoachProMenu', $iCoachMenu);
}

add_action('admin_menu', 'iCoachOptionsAddPage');

function iCoachOptionsAddPage() {
    $iCoachMenu = iCoachMenuSettings();
    add_theme_page($iCoachMenu['page_title'], $iCoachMenu['menu_title'], $iCoachMenu['capability'], $iCoachMenu['menu_slug'], $iCoachMenu['callback']);
}

function iCoachProPage(){?>
<div class="iCoachProVersion">
  <a href="<?php echo esc_url('https://indigothemes.com/products/icoach-pro-wordpress-theme/'); ?>" target="_blank">
    <img src ="<?php echo esc_url('https://indigothemes.com/wp-content/uploads/iCoach/pro-features.jpg') ?>" width="100%" height="auto" />
  </a>
</div>

<?php
}